@@ -1,7 +1,6 @@
 use chrono::Utc;
 use eyre::Result;
-use std::time::Duration;
-use std::{io::stdout, ops::Sub};
+use std::{io::stdout, ops::Sub, time::Duration};
 
 use termion::{event::Key, input::MouseTerminal, raw::IntoRawMode, screen::AlternateScreen};
 use tui::{
@@ -14,9 +13,11 @@ use tui::{
 };
 use unicode_width::UnicodeWidthStr;
 
-use atuin_client::database::Database;
-use atuin_client::history::History;
-use atuin_client::settings::{SearchMode, Settings};
+use atuin_client::{
+    database::Database,
+    history::History,
+    settings::{SearchMode, Settings},
+};
 
 use crate::command::event::{Event, Events};
 
@@ -42,7 +43,16 @@ impl State {
                 let duration: Vec<&str> = duration.split(' ').collect();
 
                 let ago = chrono::Utc::now().sub(h.timestamp);
-                let ago = humantime::format_duration(ago.to_std().unwrap()).to_string();
+
+                // Account for the chance that h.timestamp is "in the future"
+                // This would mean that "ago" is negative, and the unwrap here
+                // would fail.
+                // If the timestamp would otherwise be in the future, display
+                // the time ago as 0.
+                let ago = humantime::format_duration(
+                    ago.to_std().unwrap_or_else(|_| Duration::new(0, 0)),
+                )
+                .to_string();
                 let ago: Vec<&str> = ago.split(' ').collect();
 
                 (
@@ -76,6 +86,7 @@ impl State {
         &mut self,
         f: &mut tui::Frame<T>,
         r: tui::layout::Rect,
+        b: tui::widgets::Block,
     ) {
         let durations = self.durations();
         let max_length = durations.iter().fold(0, |largest, i| {
@@ -87,7 +98,7 @@ impl State {
             .iter()
             .enumerate()
             .map(|(i, m)| {
-                let command = m.command.to_string().replace("\n", " ").replace("\t", " ");
+                let command = m.command.to_string().replace('\n', " ").replace('\t', " ");
 
                 let mut command = Span::raw(command);
 
@@ -143,7 +154,7 @@ impl State {
             .collect();
 
         let results = List::new(results)
-            .block(Block::default().borders(Borders::ALL).title("History"))
+            .block(b)
             .start_corner(Corner::BottomLeft)
             .highlight_symbol(">> ");
 
@@ -207,6 +218,23 @@ async fn key_handler(
             app.input.pop();
             query_results(app, search_mode, db).await.unwrap();
         }
+        // \u{7f} is escape sequence for backspace
+        Key::Alt('\u{7f}') => {
+            let words: Vec<&str> = app.input.split(' ').collect();
+            if words.is_empty() {
+                return None;
+            }
+            if words.len() == 1 {
+                app.input = String::from("");
+            } else {
+                app.input = words[0..(words.len() - 1)].join(" ");
+            }
+            query_results(app, search_mode, db).await.unwrap();
+        }
+        Key::Ctrl('u') => {
+            app.input = String::from("");
+            query_results(app, search_mode, db).await.unwrap();
+        }
         Key::Down | Key::Ctrl('n') => {
             let i = match app.results_state.selected() {
                 Some(i) => {
@@ -294,9 +322,13 @@ fn draw<T: Backend>(f: &mut Frame<'_, T>, history_count: i64, app: &mut State) {
 
     f.render_widget(title, top_left_chunks[0]);
     f.render_widget(help, top_left_chunks[1]);
-
-    app.render_results(f, chunks[1]);
     f.render_widget(stats, top_right_chunks[0]);
+
+    app.render_results(
+        f,
+        chunks[1],
+        Block::default().borders(Borders::ALL).title("History"),
+    );
     f.render_widget(input, chunks[2]);
 
     f.set_cursor(
@@ -307,6 +339,70 @@ fn draw<T: Backend>(f: &mut Frame<'_, T>, history_count: i64, app: &mut State) {
     );
 }
 
+#[allow(clippy::cast_possible_truncation)]
+fn draw_compact<T: Backend>(f: &mut Frame<'_, T>, history_count: i64, app: &mut State) {
+    let chunks = Layout::default()
+        .direction(Direction::Vertical)
+        .margin(0)
+        .horizontal_margin(1)
+        .constraints(
+            [
+                Constraint::Length(1),
+                Constraint::Min(1),
+                Constraint::Length(1),
+            ]
+            .as_ref(),
+        )
+        .split(f.size());
+
+    let header_chunks = Layout::default()
+        .direction(Direction::Horizontal)
+        .constraints(
+            [
+                Constraint::Ratio(1, 3),
+                Constraint::Ratio(1, 3),
+                Constraint::Ratio(1, 3),
+            ]
+            .as_ref(),
+        )
+        .split(chunks[0]);
+
+    let title = Paragraph::new(Text::from(Span::styled(
+        format!("Atuin v{}", VERSION),
+        Style::default().fg(Color::DarkGray),
+    )));
+
+    let help = Paragraph::new(Text::from(Spans::from(vec![
+        Span::styled("Esc", Style::default().add_modifier(Modifier::BOLD)),
+        Span::raw(" to exit"),
+    ])))
+    .style(Style::default().fg(Color::DarkGray))
+    .alignment(Alignment::Center);
+
+    let stats = Paragraph::new(Text::from(Span::raw(format!(
+        "history count: {}",
+        history_count,
+    ))))
+    .style(Style::default().fg(Color::DarkGray))
+    .alignment(Alignment::Right);
+
+    let input = Paragraph::new(format!("] {}", app.input.clone())).block(Block::default());
+
+    f.render_widget(title, header_chunks[0]);
+    f.render_widget(help, header_chunks[1]);
+    f.render_widget(stats, header_chunks[2]);
+
+    app.render_results(f, chunks[1], Block::default());
+    f.render_widget(input, chunks[2]);
+
+    f.set_cursor(
+        // Put cursor past the end of the input text
+        chunks[2].x + app.input.width() as u16 + 2,
+        // Move one line down, from the border to the input line
+        chunks[2].y + 1,
+    );
+}
+
 // this is a big blob of horrible! clean it up!
 // for now, it works. But it'd be great if it were more easily readable, and
 // modular. I'd like to add some more stats and stuff at some point
@@ -314,6 +410,7 @@ fn draw<T: Backend>(f: &mut Frame<'_, T>, history_count: i64, app: &mut State) {
 async fn select_history(
     query: &[String],
     search_mode: SearchMode,
+    style: atuin_client::settings::Style,
     db: &mut (impl Database + Send + Sync),
 ) -> Result<String> {
     let stdout = stdout().into_raw_mode()?;
@@ -342,7 +439,18 @@ async fn select_history(
             }
         }
 
-        terminal.draw(|f| draw(f, history_count, &mut app))?;
+        let compact = match style {
+            atuin_client::settings::Style::Auto => {
+                terminal.size().map(|size| size.height < 14).unwrap_or(true)
+            }
+            atuin_client::settings::Style::Compact => true,
+            atuin_client::settings::Style::Full => false,
+        };
+        if compact {
+            terminal.draw(|f| draw_compact(f, history_count, &mut app))?;
+        } else {
+            terminal.draw(|f| draw(f, history_count, &mut app))?;
+        }
     }
 }
 
@@ -378,7 +486,7 @@ pub async fn run(
     };
 
     if interactive {
-        let item = select_history(query, settings.search_mode, db).await?;
+        let item = select_history(query, settings.search_mode, settings.style, db).await?;
         eprintln!("{}", item);
     } else {
         let results = db
